@@ -22,6 +22,9 @@ package tech.libeufin.common.db
 import tech.libeufin.common.BankPaytoCtx
 import tech.libeufin.common.Payto
 import tech.libeufin.common.TalerAmount
+import tech.libeufin.common.DecimalNumber
+import tech.libeufin.common.TalerProtocolTimestamp
+import tech.libeufin.common.asInstant
 import java.sql.ResultSet
 
 fun ResultSet.getAmount(name: String, currency: String): TalerAmount {
@@ -32,6 +35,23 @@ fun ResultSet.getAmount(name: String, currency: String): TalerAmount {
     )
 }
 
+fun ResultSet.getOptAmount(name: String, currency: String): TalerAmount? {
+    val amount = getAmount(name, currency)
+    if (wasNull()) return null
+    return amount
+}
+
+fun ResultSet.getDecimal(name: String): DecimalNumber {
+    return DecimalNumber(
+        getLong("${name}_val"),
+        getInt("${name}_frac")
+    )
+}
+
+fun ResultSet.getTalerTimestamp(name: String): TalerProtocolTimestamp{
+    return TalerProtocolTimestamp(getLong(name).asInstant())
+}
+
 fun ResultSet.getBankPayto(payto: String, name: String, ctx: BankPaytoCtx): String {
     return Payto.parse(getString(payto)).bank(getString(name), ctx)
 }
\ No newline at end of file
