@@ -20,7 +20,9 @@
 import org.junit.Test
 import tech.libeufin.nexus.parseCustomerAck
 import tech.libeufin.nexus.parseCustomerPaymentStatusReport
-import tech.libeufin.nexus.parseTxNotif
+import tech.libeufin.nexus.parseTx
+import tech.libeufin.nexus.loadConfig
+import tech.libeufin.nexus.ebics.Dialect
 import java.nio.file.Files
 import kotlin.io.path.Path
 import kotlin.io.path.exists
@@ -36,10 +38,10 @@ class Iso20022Test {
             println(name)
             if (name.contains("HAC")) {
                 parseCustomerAck(content)
-            } else if (name.contains("pain.002")) {
+            } else if (name.contains("pain.002") || name.contains("pain002") ) {
                 parseCustomerPaymentStatusReport(content)
             } else {
-                parseTxNotif(content, "CHF")
+                parseTx(content, "CHF", Dialect.postfinance)
             }
         }
     }
@@ -49,20 +51,26 @@ class Iso20022Test {
         val root = Path("test")
         if (!root.exists()) return
         for (platform in root.listDirectoryEntries()) {
+            if (!platform.isDirectory()) continue
             for (file in platform.listDirectoryEntries()) {
+                if (!file.isDirectory()) continue
                 val fetch = file.resolve("fetch")
-                if (file.isDirectory() && fetch.exists()) {
-                    for (log in fetch.listDirectoryEntries()) {
-                        val content = Files.newInputStream(log)
-                        val name = log.toString()
-                        println(name)
-                        if (name.contains("HAC")) {
-                            parseCustomerAck(content)
-                        } else if (name.contains("pain.002")) {
-                            parseCustomerPaymentStatusReport(content)
-                        } else {
-                            parseTxNotif(content, "CHF")
-                        }
+                if (!fetch.exists()) continue
+                val cfg = loadConfig(platform.resolve("ebics.conf"))
+                val currency = cfg.requireString("nexus-ebics", "currency")
+                val dialect = Dialect.valueOf(cfg.requireString("nexus-ebics", "bank_dialect"))
+                for (log in fetch.listDirectoryEntries()) {
+                    val content = Files.newInputStream(log)
+                    val name = log.toString()
+                    println(name)
+                    if (name.contains("HAC")) {
+                        parseCustomerAck(content)
+                    } else if (name.contains("pain.002")) {
+                        parseCustomerPaymentStatusReport(content)
+                    } else if (
+                        !name.contains("camt.052") && !name.contains("_C52_") && !name.contains("_Z01_")
+                    ) {
+                        parseTx(content, currency, dialect)
                     }
                 }
             }
